
#include "uinavlist.h"

#include <qvariant.h>
#include <qlistbox.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>

/*
 *  Constructs a UINavList as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
UINavList::UINavList( QWidget* parent, const char* name, WFlags fl )
        : QWidget( parent, name, fl ) {
    if ( !name )
        setName( "UINavList" );
    UINavListLayout = new QVBoxLayout( this, 2, 6, "UINavListLayout");

    m_listBox = new QListBox( this, "m_listBox" );
    UINavListLayout->addWidget( m_listBox );

    layout1 = new QHBoxLayout( 0, 0, 6, "layout1");
    spacer2 = new QSpacerItem( 41, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout1->addItem( spacer2 );

    m_buttonUp = new QPushButton( this, "m_buttonUp" );
    m_buttonUp->setEnabled( FALSE );
    layout1->addWidget( m_buttonUp );

    m_buttonDown = new QPushButton( this, "m_buttonDown" );
    m_buttonDown->setEnabled( FALSE );
    layout1->addWidget( m_buttonDown );
    spacer1 = new QSpacerItem( 51, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout1->addItem( spacer1 );
    UINavListLayout->addLayout( layout1 );
    languageChange();
//    resize( QSize(225, 143).expandedTo(minimumSizeHint()) );
//    clearWState( WState_Polished );

    // signals and slots connections
    connect( m_buttonUp, SIGNAL( clicked() ), this, SLOT( moveUp() ) );
    connect( m_buttonDown, SIGNAL( clicked() ), this, SLOT( moveDown() ) );
    connect( m_listBox, SIGNAL( highlighted(QListBoxItem*) ), this, SLOT( onClicked(QListBoxItem*) ) );
}

/*
 *  Destroys the object and frees any allocated resources
 */
UINavList::~UINavList() {
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void UINavList::languageChange() {
    m_buttonUp->setText( tr( "Up" ) );
    m_buttonDown->setText( tr( "Down" ) );
}

void UINavList::moveUp() {
    qWarning( "UINavList::moveUp(): Not implemented yet" );
}

void UINavList::moveDown() {
    qWarning( "UINavList::moveDown(): Not implemented yet" );
}

void UINavList::onClicked(QListBoxItem*) {
    qWarning( "UINavList::onClicked(QListBoxItem*): Not implemented yet" );
}

