//
// C++ Interface: wwcanvasview
//
// Description:
//
//
// Author: Witold Wysota <wysota@wysota.eu.org>, (C) 2005
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef WWCANVASVIEW_H
#define WWCANVASVIEW_H

#include <qcanvas.h>
#include <qptrlist.h>

class QAction;

/**
 *  @author Witold Wysota
 *  @brief  QCanvasView with scaling and item dragging support
 *
 *          This class provides possibility to click and drag items
 *          contained and scale the canvas.
 */
class wwCanvasView : public QCanvasView
{
Q_OBJECT
Q_PROPERTY( double scaleX READ scaleX WRITE setScaleX )
Q_PROPERTY( double scaleY READ scaleY WRITE setScaleY )
Q_PROPERTY( bool dragsEnabled READ dragsEnabled WRITE setDragsEnabled )
public:
    wwCanvasView ( QWidget * parent = 0, const char * name = 0, WFlags f = 0 );
    wwCanvasView ( QCanvas * canvas, QWidget * parent = 0, const char * name = 0, WFlags f = 0 );
    ~wwCanvasView();
    double scaleX() const;
    double scaleY() const;
    virtual void setScaleX(const double sx);
    virtual void setScaleY(const double sy);
    virtual void setScale(double sx, double sy=0);
    virtual void addAction(QAction *a);
    virtual void removeAction(QAction *a);
    virtual void setDragsEnabled(bool yes);
    bool dragsEnabled() const;
protected:
    QCanvasItem *m_dragged;
    QPoint m_dragorig;
    bool m_dragsEnabled;
    void contentsMousePressEvent(QMouseEvent *e);
    void contentsMouseMoveEvent(QMouseEvent *e);
    void contentsMouseReleaseEvent(QMouseEvent *e);
    void contentsContextMenuEvent(QContextMenuEvent *e);
    QPtrList<QAction> m_actionlist;
public slots:
    virtual void Double();
    virtual void Halve();
signals:
    void clicked(QCanvasItem *);                    ///< Signal is emitted when an item is clicked
    void dragged(QCanvasItem *, const QPoint &pt);  ///< Signal is emitted when an item is dragged
};

#endif
