#ifndef WWLINEEDIT_H
#define WWLINEEDIT_H

#include <qlineedit.h>
#include <qregexp.h>
#include <qvalidator.h>

/**
 * @class wwLineEdit
 * @brief LineEdit with regexp validation
 *
 *        This class provides an additional functionality to QLineEdit by making
 *        it possible to provide a regular expression (aka regexp) that will
 *        control validation of the input.
 *
 */
class wwLineEdit : public QLineEdit {
    Q_OBJECT
    Q_PROPERTY( QString regExp READ regExp WRITE setRegExp )
public:
    wwLineEdit(QWidget *parent=0, const char *name=0);                ///< Default widget constructor
    ~wwLineEdit();
    const QString regExp() const;                                     ///< Returns the regular expression currently set
public slots:
    void setRegExp(const QString &);                                  ///< Sets a regular expression to validate input
    void clearValidator();                                            ///< Clears current regular expression
    void setValidator ( const QValidator * v );                       ///< Sets a validator (see QLineEdit::setValidator for details)
signals:
    void regExpChanged(const QString &);                              ///< The signal is emitted when the regular expression changes
protected:
    QRegExpValidator val;
};

#endif
