//
// C++ Interface: wwListBoxNav
//
// Description:
//
//
// Author: Witold Wysota <wysota@wysota.eu.org>, (C) 2006
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "wwlistboxnav.h"
#include <qpushbutton.h>
#include <qlistbox.h>

wwListBoxNav::wwListBoxNav(QWidget *parent, const char *name)
        :UINavList(parent, name) {}

/**
 * @brief Moves current item upwards
 *
 */
void wwListBoxNav::moveUp() {
    emit upClicked();
    //unsigned int curr = m_listBox->currentItem();
    QListBoxItem *it = m_listBox->selectedItem();
    if(!it)
        return;
    m_listBox->clearSelection();
    QListBoxItem *prev = it->prev();
    if(prev) {
        m_listBox->takeItem(prev);
        m_listBox->insertItem(prev,it);
        emit movedUp(it);
    }
    m_listBox->setSelected(it, true);
    onClicked(it);
}

/**
 * @brief Moves current item downwards
 *
 */
void wwListBoxNav::moveDown() {
    emit downClicked();
    QListBoxItem *it = m_listBox->selectedItem();
    if(!it)
        return;
    m_listBox->clearSelection();
    QListBoxItem *next = it->next();
    if(next) {
        m_listBox->takeItem(it);
        m_listBox->insertItem(it, next);
        emit movedDown(it);
    }
    m_listBox->setSelected(it, true);
    onClicked(it);
}

/**
 *  @brief Slot invoked when the listbox is clicked.
 *
 *  @param it pointer to item clicked
 */
void wwListBoxNav::onClicked(QListBoxItem *it) {
    if(!it) {
        m_buttonUp->setEnabled(false);
        m_buttonDown->setEnabled(false);
        return;
    }
    m_buttonUp->setEnabled((it->prev()!=0));
    m_buttonDown->setEnabled((it->next()!=0));
}

/**
 *  @brief Returns pointer to the QListBox object
 *  @return pointer to the list box
 */
const QListBox * wwListBoxNav::listBox( ) {
    return m_listBox;
}

/**
 *  @brief Returns pointer to the "up" button
 *  @return pointer to "up" QPushButton
 */
const QPushButton * wwListBoxNav::upButton( ) {
    return m_buttonUp;
}

/**
 *  @brief Returns pointer to the "down" button
 *  @return pointer to "down" QPushButton
 */
const QPushButton * wwListBoxNav::downButton( ) {
    return m_buttonDown;
}

/**
 *  @brief Inserts an item to the listbox
 *  @param text text to be inserted
 */
void wwListBoxNav::insertItem( const QString & text ) {
    m_listBox->insertItem(text);
}

/**
 *  @brief Inserts an item to the listbox
 *  @param item item to be inserted
 */
void wwListBoxNav::insertItem( QListBoxItem * item ) {
    m_listBox->insertItem(item);
}


/**
 * @brief Removes the selected item from listbox
 *
 */
void wwListBoxNav::removeSelected( ) {
    QListBoxItem *sel = m_listBox->selectedItem();
    if(!sel)
        return;
    if(sel->next())
        m_listBox->setSelected(sel->next(),true);
    m_listBox->removeItem(m_listBox->index(sel));
    emit itemRemoved();
}

