#include "wwplugins.h"
#include "wwclasses.h"
#ifndef NO_WWPLOT
#include "wwplot.h"
#endif
#include "wwlineedit.h"
#include "wwfloatspinbox.h"
#include "wwlistboxnav.h"
#include "wwcanvasview.h"
#include "icons.h"
#include <qcanvas.h>
#include <qworkspace.h>
#include <qtabbar.h>
#include <qgl.h>

Q_EXPORT_PLUGIN( wwPlugins )

/**
@mainpage   wwWidgets
@author     Witold Wysota

This is a set of widgets for Qt3 with a plugin that makes them available in Qt Designer.

*/

static char *__plugindata[][4] = {   /* name             include file        group          tooltip*/
#ifndef NO_WWPLOT
                                     { "wwPlot",         "wwplot.h",         "wwClasses",  ""                                  },
#endif
                                     { "QCanvasView",    "qcanvas.h",        "Views",      "QCanvasView"                       },
                     { "wwCanvasView",    "wwcanvasview.h",        "Views",      "wwCanvasView"                       },
                                     { "QWorkspace",     "qworkspace.h",     "Views",      "QWorkspace"                        },
                                     { "QGLWidget",      "qgl.h",            "Display",    "QGLWidget"                         },
                                     { "wwActiveLabel",  "wwclasses.h",      "wwClasses",  "Clickable label"                   },
                                     { "wwLineEdit",     "wwlineedit.h",     "wwClasses",  "Line edit with regexp validator"   },
                                     { "wwFloatSpinBox", "wwfloatspinbox.h", "wwClasses",  "Spin box that displays real values" },
                     { "wwListBoxNav",   "wwlistboxnav.h",   "wwClasses",  "List box with navigation" },
                                     { 0,                 0,                 0,            0                                   }
                                 };


wwPlugins::wwPlugins() {}

QStringList wwPlugins::keys() const {
    QStringList list;
    for(int i=0; __plugindata[i][0]!=0; i++)
        list << __plugindata[i][0];

    return list;
}

QWidget* wwPlugins::create( const QString &key, QWidget* parent, const char* name ) {
    if ( key == "wwActiveLabel" )
        return new wwActiveLabel( parent, name );
    if ( key == "QCanvasView" )
        return new QCanvasView( parent, name );
    if ( key == "wwCanvasView" )
        return new wwCanvasView( parent, name );
    if ( key == "QWorkspace" )
        return new QWorkspace( parent, name );
    if ( key == "QGLWidget" )
        return new QGLWidget( parent, name );
#ifndef NO_WWPLOT

    if ( key == "wwPlot" )
        return new wwPlot( parent, name );
#endif

    if ( key == "wwLineEdit" )
        return new wwLineEdit( parent, name );
    if ( key == "wwFloatSpinBox" )
        return new wwFloatSpinBox( parent, name );
    if ( key == "wwListBoxNav" )
        return new wwListBoxNav( parent, name );
    return 0;
}

QString wwPlugins::group( const QString& feature ) const {
    for(int i=0; __plugindata[i][0]!=0; i++) {
        if( feature == __plugindata[i][0])
            return __plugindata[i][2];
    }

    return QString::null;
}

QIconSet wwPlugins::iconSet( const QString& feature ) const {
    if(feature == "wwLineEdit")
        return QIconSet( QPixmap( (const char**)lineedit_xpm));
    if(feature == "wwFloatSpinBox")
        return QIconSet( QPixmap( (const char**)spinbox_xpm));
    if(feature == "wwActiveLabel")
        return QIconSet( QPixmap( (const char**)label_xpm));
    if(feature == "QGLWidget")
        return QIconSet( QPixmap( (const char**)glwidget_xpm));
#ifndef NO_WWPLOT

    if(feature == "wwPlot")
        return QIconSet( QPixmap( (const char**)plot_xpm));
#endif

    return QIconSet( QPixmap( (const char**)wwxpm ) );
}



QString wwPlugins::includeFile( const QString& feature ) const {
    for(int i=0; __plugindata[i][0]!=0; i++) {
        if( feature == __plugindata[i][0])
            return __plugindata[i][1];
    }
    return QString::null;
}

QString wwPlugins::toolTip( const QString& feature ) const {
    for(int i=0; __plugindata[i][0]!=0; i++) {
        if( feature == __plugindata[i][0])
            return __plugindata[i][3];
    }
    return QString::null;
}

QString wwPlugins::whatsThis( const QString& feature ) const {
    if ( feature == "wwActiveLabel" )
        return "A clickable label";
    if ( feature == "QCanvasView" )
        return "QCanvasView";
    if ( feature == "QWorkspace" )
        return "QWorkspace";
    if ( feature == "wwLineEdit" )
        return "LineEdit with Regexp validator";
    if ( feature == "wwFloatSpinBox" )
        return "Spin box that displays real values";
    return QString::null;
}

bool wwPlugins::isContainer( const QString& ) const {
    return false;
}
